
# Unit test: detect hard-coded absolute paths in the code

library(lintr)

detect_hardcoded_paths <- function() {
  
  # Define the directories to check
  directories <- c("modules", "tools")
  
  # Define custom lintr to detect the string "/esarchive/"
  esarchive_linter <- function(source_file) {
    lines <- readLines(soure_file, warn = FALSE)
    # Remove comments: everything from '#' to the end of line
    code_lines <- gsub("#.*$", "", lines)
    # Check if any cleaned line contains "/esarchive/"
    if (any(grepl("/esarchive/", code_lines))) {
      lint <- lintr::Lint(
        filename = source_file,
        line_number = which(grepl("/esarchive/", code_lines)),
        column_number = NULL,
        type = "error",
        message = "Hard-coded path '/esarchive/' found.",
        linter = "esarchive_linter"
      )
      return(list(lint)) # Returns list of lint objects
    }
    return(list()) # Returns empty list if "/esarchive/" not found
  }
  
  # Apply the custom linter to each directory and save results
  files_with_issues <- unlist(lapply(directories, function(dir) {
    lint_dir(path = dir, linters = list(esarchive = esarchive_linter))
  }), recursive = TRUE)
  
  # Check results and print out the test outcome
  if (length(files_with_issues) > 0) {
    cat("Test FAILED. '/esarchive/' found in the following files:\n")
    issues_report <- vapply(files_with_issues, function(l) {
      paste(l$filename, "Line:", l$line_number) # Print file name and line number
    }, character(1))
    print(issues_report)
    return(FALSE)
  } else {
    cat("Test PASSED. No '/esarchive/' found in any file.\n")
    return(TRUE)
  }
}

